@@ -63,7 +63,8 @@ class PubSubManager(BaseManager):
             callback = None
         self._publish({'method': 'emit', 'event': event, 'data': data,
                        'namespace': namespace, 'room': room,
-                       'skip_sid': skip_sid, 'callback': callback})
+                       'skip_sid': skip_sid, 'callback': callback,
+                       'host_id': self.host_id})
 
     def close_room(self, room, namespace=None):
         self._publish({'method': 'close_room', 'room': room,
@@ -93,8 +94,9 @@ class PubSubManager(BaseManager):
         # Here in the receiving end we set up a local callback that preserves
         # the callback host and id from the sender
         remote_callback = message.get('callback')
+        remote_host_id = message.get('host_id')
         if remote_callback is not None and len(remote_callback) == 3:
-            callback = partial(self._return_callback, self.host_id,
+            callback = partial(self._return_callback, remote_host_id,
                                *remote_callback)
         else:
             callback = None
